PyXMake Developer Guide: PyXMake.VTL.stm_make.pyx_pytest Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Static Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.pyx_pytest Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pyx_pytest:

## Public Member Functions
| initialize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseTest
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)

## Public Attributes
int | verbose = 0
str | source_path = ''
| output_file_path = os.getcwd()
| scratch_path = os.getcwd()
| include = None
Public Attributes inherited from PyXMake.VTL.stm_make._BaseTest
str | command = "py.test"
| out = None
| covout = None
| verbose = self.distribution.verbose
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Static Public Attributes
str | description = "Run predefined unit tests using Pytest."
list | user_options
Static Public Attributes inherited from PyXMake.VTL.stm_make._BaseTest
str | description = "Runs all unit tests using py.test."
list | user_options

## Protected Member Functions
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_command (self)
| _perform_post_actions (self)

## Static Protected Attributes
str | _PACKAGE_NAME = ''

## Additional Inherited Members
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Base class for encapsulating pytest commands.

Definition at line 1000 of file stm_make.py.

## Member Function Documentation

## ◆ _run_command()

PyXMake.VTL.stm_make.pyx_pytest._run_command | ( |  | self,
|  |  | command )
| protected

    Execute test command

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 1026 of file stm_make.py.

## ◆ initialize_options()

PyXMake.VTL.stm_make.pyx_pytest.initialize_options | ( |  | self | ) |

    Set default values for all options.

Reimplemented from PyXMake.VTL.stm_make._BaseTest.

Definition at line 1015 of file stm_make.py.

## Member Data Documentation

## ◆ _PACKAGE_NAME

str PyXMake.VTL.stm_make.pyx_pytest._PACKAGE_NAME = ''
| staticprotected

Definition at line 1004 of file stm_make.py.

## ◆ description

str PyXMake.VTL.stm_make.pyx_pytest.description = "Run predefined unit tests using Pytest."
| static

Definition at line 1006 of file stm_make.py.

## ◆ include

PyXMake.VTL.stm_make.pyx_pytest.include = None

Definition at line 1024 of file stm_make.py.

## ◆ output_file_path

PyXMake.VTL.stm_make.pyx_pytest.output_file_path = os.getcwd()

Definition at line 1022 of file stm_make.py.

## ◆ scratch_path

PyXMake.VTL.stm_make.pyx_pytest.scratch_path = os.getcwd()

Definition at line 1023 of file stm_make.py.

## ◆ source_path

str PyXMake.VTL.stm_make.pyx_pytest.source_path = ''

Definition at line 1021 of file stm_make.py.

## ◆ user_options

list PyXMake.VTL.stm_make.pyx_pytest.user_options
| static

Initial value:
= [
# The format is (long option, short option, description).
('output-file-path=', None, 'path to the output directory'),
('source-path=', None, 'path to the folder holding source files'),
('scratch-path=', None, 'path to scratch folder where all temporary data is located during the build event'),
('verbose=', None, 'controls the logging level (0 - Nothing, 2- Everything) Default: 0 - Nothing'),
]

Definition at line 1007 of file stm_make.py.

## ◆ verbose

int PyXMake.VTL.stm_make.pyx_pytest.verbose = 0

Definition at line 1020 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py